let utils = light.util;
let config = light.config;
let shell = utils.require('shelljs');

let vueTemplate = utils.template(`
/**AUTO-GEN-START*/
import __VUE__ from "vue"
__VUE__.use(__LIGHT__);
import __LIGHT__ from "light"
__LIGHT__
<%views.forEach(function(view){%>
.route({
    path: '/<%=view.id%>',
    <%if(view.async){%>component: ()=>{return import("./<%=view.id%>.vue")},<%}%>
    <%if(!view.async){%>component: require("./<%=view.id%>.vue"),<%}%>
    <%if(view.parent){%>parent:"/<%=view.parent%>",<%}%>
    <%if(view.home){%>home:"/<%=view.home%>",<%}%>
})
<%})%>
/**AUTO-GEN-END*/
`);

module.exports = {
    pluginName:"type-vue",
    install:function (light) {
    },

    /**
     * 准备阶段
     */
    prepare:function (light,cb) {
        //准备编译
        let promise;

        //1. 自定义标签的处理
        //1.1 view标签的处理
        promise = new Promise(function (resolve, reject) {
            utils.glob(`${config.dist}/*.html`,function (err, files) {

                files.forEach(function (file) {
                    let $ = utils.require("cheerio").load(utils.readFileSync(file), {
                        recognizeSelfClosing: true
                    });

                    let views = $("view");
                    views.first().replaceWith("<router-view></router-view>");
                    views.remove();

                    //replace知会替换第一个匹配到的内容
                    // let dist = file.replace(config.src,config.dist);
                    // if(utils.existsSync(dist)){
                    //     utils.removeSync(dist)
                    // }

                    // $(`<script src="bundle.js"></script>`).insertBefore($("script").first())

                    utils.outputFile(file,$.html(),(err)=>{
                        resolve(views)
                    });
                })
            })
        });

        //1.2 根据视图内容生成视图注册的模板，注册路由
        promise = promise.then(function (views) {
            let v = [];
            views.each(function (i,view) {
                v.push(view.attribs)
            });

            let vueViewString = vueTemplate({views:v});

            utils.writeFileSync(`${config.dist}/view/index.js`,`${vueViewString}`);
        });

        //END
        promise.then(cb);
    },

    /**
     * 编译阶段
     */
    build(light,cb){
        //2 编译，通过webpack把所有资源整合起来
        new Promise(function (resolve,reject) {
            process.chdir(config.dist);
            if(!utils.existsSync(`${config.dist}/node_modules`)) shell.ln(`-s`,`${__dirname}/node_modules`,`${config.dist}/node_modules`);

            //环境变量
            process.env.NODE_ENV = process.env.NODE_ENV || "production";
            return require("./build").build().then(resolve);
        }).then(cb);
    },

    /**
     * 打包阶段
     */
    packager(light,cb){
        shell.rm("-fr",`${config.dist}/view`);
        shell.rm("-fr",`${config.dist}/ui`);
        shell.rm("-fr",`${config.dist}/html`);
        shell.rm("-fr",`${config.dist}/js`);
        shell.rm("-fr",`${config.dist}/lib`);
        shell.rm("-fr",`${config.dist}/plugins`);
        if(utils.existsSync(`${config.dist}/node_modules`)) shell.rm(`${config.dist}/node_modules`);
        cb();
    },

    /**
     * 运行阶段
     */
    runtime:function () {

    }
};