let webpack = require('webpack');
process.traceDeprecation = false;
process.noDeprecation = true;

let config = {
    entry:{
        app:[
            `${light.config.dist}/view/index.js`,
            `${light.config.dist}/app.js`,
        ]
    },
    module: {
        rules: [
            {
                test: /\.(less|css)$/,
                use: [{
                    loader: "style-loader" // creates style nodes from JS strings
                }, {
                    loader: "css-loader" // translates CSS into CommonJS
                }, {
                    loader: "less-loader" // compiles Less to CSS
                }]
            },
            {
                test: /\.js$/,
                //去除node_modules目录的es6转es5流程，加快编译速度
                exclude: process.env.NODE_ENV === "dev" ? /(node_modules|bower_components)/ : undefined,
                use: {
                    loader: 'babel-loader',
                    options: {
                        presets: ['es2015'],
                        plugins: ['syntax-dynamic-import',"transform-class-properties"],
                        compact: 'false'
                    }
                }
            },
            {
                test: /\.(png|jpg|gif|svg|ttf|woff|eot)$/,
                loader: 'file-loader',
                options: {
                    name: 'assets/[name].[ext]?[hash]'
                }
            }
        ]
    },
    resolve: {
        extensions: ['.js', '.vue', '.json'],
        modules: [`${__dirname}/node_modules`, "lib/node_modules", "lib"],
        alias: {
            "light": `olight/dist/olight.js`,
            'vue': "vue/dist/vue.esm"
        }
    },
    plugins: [
        new require('progress-bar-webpack-plugin')({
            format: '  编译中 [:bar] ' + require("chalk").green.bold(':percent') + ' (:elapsed 秒)',
            clear: false
        }),

    ]
};

if (light.options.uglify) {
    config = require("webpack-merge")({
        plugins: [
            new webpack.optimize.UglifyJsPlugin({
                compress: {
                    warnings: false
                }
            })
        ]
    }, config)
}

module.exports = config;